# IoT JumpWay Python MQTT Client Package

![TechBubble IoT JumpWay Docs](Media/Images/IoT-Jumpway.jpg)  

## Introduction

The Internet of Things (IoT) JumpWay is an IoT PaaS that allows anyone to connect IoT devices such as Raspberry Pi, Intel, Arduino, ESP8266 and even phones, PCs, Macs and laptops to the Internet of Things. The IoT JumpWay examples allow you to connect devices and sensors to the IoT JumpWay and control/monitor sensors/actuators and data to and from the devices.

The Python MQTT Client Package allows developers to communicate with the IoT JumpWay MQTT Broker and provides a number of device and applications examples.

### Library Installation

In all cases, whether using devices or applications you first need to install the library. 

- Install the latest version of the library with pip

```
    $ pip/pip3 install JumpWayMQTT
```

- Upgrade to the latest version of the library with pip

```
    $ pip/pip3 install JumpWayMQTT --upgrade
```